@@ -530,9 +530,6 @@ sending `inferior-ess-language-start' to S-Plus.")
 ;; is currently used (updated) by ess-find-newest-R
 (defvar ess-r-versions-created nil
   "List of strings of all R-versions found on the system.")
-;; FIXME: should then update ess-versions-created as well (easy),
-;; -----  *and* update the "Start Process" menu (below)
-;;    -> To this: wrap the following in functions that can be re-called
 
 (defun ess-r-s-versions-creation ()
   "(Re)Create ESS  R-<..> commands FILENAME sans final \"extension\".
@@ -597,21 +594,30 @@ The extension, in a file name, is the part that follows the last `.'."
            (mapcar (lambda(x) (if (boundp x) (symbol-value x) nil))
                    '(R-newest-list
                      ess-r-versions-created
-                     ess-s-versions-created)))))
-  )
+                     ess-s-versions-created))))))
 
-(ess-message "[ess-site:] before (ess-r-s-versions-creation) ...")
-(ess-r-s-versions-creation)
+(defun ess-r-s-versions-creation+menu ()
+  "Call `\\[ess-r-s-versions-creation] creaing `ess-versions-created' and
+update the \"Start Process\" menu."
+  (interactive)
+  (ess-message "[ess-site:] before (ess-r-s-versions-creation) ...")
+  (ess-r-s-versions-creation)
 
-(when ess-versions-created
-  ;; new-menu will be a list of 3-vectors, of the form:
-  ;; ["R-1.8.1" R-1.8.1 t]
-  (let ((new-menu (mapcar (lambda(x) (vector x (intern x) t))
+  (when ess-versions-created
+    ;; new-menu will be a list of 3-vectors, of the form:
+    ;; ["R-1.8.1" R-1.8.1 t]
+    (let ((new-menu (mapcar (lambda(x) (vector x (intern x) t))
                           ess-versions-created)))
-    (easy-menu-add-item ess-mode-menu '("Start Process")
-                        (cons "Other" new-menu))))
+      (easy-menu-add-item ess-mode-menu '("Start Process")
+                          (cons "Other" new-menu))))
+
+  (ess-message "[ess-site:] after ess-versions-created ...")
+  ;; return
+  ess-versions-created)
+
+;; call it 
+(ess-r-s-versions-creation+menu)
 
-(ess-message "[ess-site:] after ess-versions-created ...")
 
 ;; Check to see that inferior-R-program-name points to a working version
 ;; of R; if not, try to find the newest version:
