@@ -822,7 +822,7 @@ evaluation of BODY.
 Should be used in `ess-idle-timer-functions' which call the
 process to avoid excessive requests.
 "
-  (declare (indent 1))
+  (declare (indent 1) (debug t))
   `(with-ess-process-buffer 'no-error
      (let ((le (process-get *proc* 'last-eval))
            (tv (process-get *proc* ',time-var)))
@@ -877,7 +877,7 @@ t. See examples in the tracebug code.
 (defmacro ess-execute-dialect-specific (command &optional prompt &rest args)
   "Execute dialect specific command.
 
--- If command is not defined issue warning 'Not availabe for dialect X'
+-- If command is not defined issue warning 'Not available for dialect X'
 -- if a function, execute it with ARGS
 -- If a string starting with 'http' or 'www', browse with `browse-url',
    otherwise execute the command in inferior process.
@@ -1083,8 +1083,7 @@ queried for arguments.
               (if args
                   (setcar args (cons (car args) (current-time)))))
             ;; push even if nil
-            (puthash (substring-no-properties funname) args (process-get proc 'funargs-cache))
-            )))))
+            (puthash (substring-no-properties funname) args (process-get proc 'funargs-cache)))))))
 
 (defun ess-symbol-start ()
   "Get initial position for objects completion."
@@ -1093,6 +1092,14 @@ queried for arguments.
                                         (looking-at "/\\|.[0-9]"))))
       beg)))
 
+(defun ess-arg-start ()
+  "Get initial position for args completion"
+  (when (not (ess-inside-string-p))
+    (when (ess--funname.start)
+      (if (looking-back "[(,]+[ \t\n]*")
+          (point)
+        (ess-symbol-start)))))
+
 (defvar ess--funname.start nil)
 
 (defun ess--funname.start (&optional look-back)
@@ -1119,7 +1126,7 @@ later."
 
        (unless (ess-inside-string-p)
          (setq ess--funname.start
-               (condition-case nil ;; check if it is inside a functon 
+               (condition-case nil ;; check if it is inside a functon
                    (progn
                      ;; for the sake of big buffers, look only 1000 chars back
                      (narrow-to-region (max (point-min) (- (point) 1000)) (point))
